# PSAS Packet Serializer

[![build status](https://travis-ci.org/psas/packet-serializer.png)](https://travis-ci.org/psas/packet-serializer)

Reusable PSAS telemetry packet encoder, decoder, documentation, and other tools.

### Documentation:

<http://psas-packet-serializer.readthedocs.org/>

## Install

    pip install -e git+https://github.com/psas/packet-serializer.git

## Develop

Install locally in a virtual env

    python setup.py install

Do work and test

    python setup.py test


## License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
